==> meilisearch_fastapi-0.19.0-py3-none-any.whl: meilisearch_fastapi/models/index.py <==
from typing import Dict, List, Optional

from camel_converter.pydantic_base import CamelBase
from meilisearch_python_sdk.models.settings import Faceting
from meilisearch_python_sdk.models.settings import TypoTolerance as TypoToleranceInfo


class FacetingWithUID(Faceting):
    uid: str


class FilterableAttributes(CamelBase):
    filterable_attributes: Optional[List[str]] = None


class FilterableAttributesWithUID(FilterableAttributes):
    uid: str


class DisplayedAttributes(CamelBase):
    displayed_attributes: List[str]


class DisplayedAttributesUID(DisplayedAttributes):
    uid: str


class DistinctAttribute(CamelBase):
    attribute: Optional[str] = None


class DistinctAttributeWithUID(CamelBase):
    uid: str
    attribute: str


class IndexUpdate(CamelBase):
    uid: str
    primary_key: Optional[str] = None


class RankingRules(CamelBase):
    ranking_rules: List[str]


class RankingRulesWithUID(RankingRules):
    uid: str


class PrimaryKey(CamelBase):
    primary_key: Optional[str] = None


class SearchableAttributes(CamelBase):
    searchable_attributes: List[str]


class SearchableAttributesWithUID(SearchableAttributes):
    uid: str


class SortableAttributes(CamelBase):
    sortable_attributes: List[str]


class SortableAttributesWithUID(SortableAttributes):
    uid: str


class StopWords(CamelBase):
    stop_words: Optional[List[str]] = None


class StopWordsWithUID(StopWords):
    uid: str


class Synonyms(CamelBase):
    synonyms: Optional[Dict[str, List[str]]] = None


class SynonymsWithUID(Synonyms):
    uid: str


class TypoTolerance(CamelBase):
    typo_tolerance: Optional[TypoToleranceInfo] = None


class TypoToleranceWithUID(TypoTolerance):
    uid: str

==> meilisearch_fastapi-0.20.0-py3-none-any.whl: meilisearch_fastapi/models/index.py <==
from __future__ import annotations

from camel_converter.pydantic_base import CamelBase
from meilisearch_python_sdk.models.settings import Faceting
from meilisearch_python_sdk.models.settings import TypoTolerance as TypoToleranceInfo


class FacetingWithUID(Faceting):
    uid: str


class FilterableAttributes(CamelBase):
    filterable_attributes: list[str] | None = None


class FilterableAttributesWithUID(FilterableAttributes):
    uid: str


class DisplayedAttributes(CamelBase):
    displayed_attributes: list[str]


class DisplayedAttributesUID(DisplayedAttributes):
    uid: str


class DistinctAttribute(CamelBase):
    attribute: str | None = None


class DistinctAttributeWithUID(CamelBase):
    uid: str
    attribute: str


class IndexUpdate(CamelBase):
    uid: str
    primary_key: str | None = None


class RankingRules(CamelBase):
    ranking_rules: list[str]


class RankingRulesWithUID(RankingRules):
    uid: str


class PrimaryKey(CamelBase):
    primary_key: str | None = None


class SearchableAttributes(CamelBase):
    searchable_attributes: list[str]


class SearchableAttributesWithUID(SearchableAttributes):
    uid: str


class SortableAttributes(CamelBase):
    sortable_attributes: list[str]


class SortableAttributesWithUID(SortableAttributes):
    uid: str


class StopWords(CamelBase):
    stop_words: list[str] | None = None


class StopWordsWithUID(StopWords):
    uid: str


class Synonyms(CamelBase):
    synonyms: dict[str, list[str]] | None = None


class SynonymsWithUID(Synonyms):
    uid: str


class TypoTolerance(CamelBase):
    typo_tolerance: TypoToleranceInfo | None = None


class TypoToleranceWithUID(TypoTolerance):
    uid: str
